@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -34,16 +34,13 @@ It is the very first thing that is loaded when starting pyFormex.
 import datetime
 start_time = datetime.datetime.now()
 
-import os, sys
-import importlib
-import importlib.machinery
-import importlib.util
+import os
+import sys
 import logging
 import logging.config
-#from getpass import getuser
 
 __prog__ = "pyformex"
-__version__ = "3.3"
+__version__ = "3.4"
 __revision__ = __version__
 __branch__ = "master"
 Copyright = 'Copyright (C) 2004-2023 Benedict Verhegghe'
@@ -91,11 +88,10 @@ class ImplementationError(FatalError):
 #########  Check Python version #############
 
 # intended Python version
-# We only support 3.8+ because we use self documenting f-strings
-minimal_version = 0x03080000
-target_version = 0x03090000
-future_version = 0x030A0000
-
+# We support 3.8+ only, because we use self documenting f-strings
+_minimal_version = 0x03080000
+_target_version = 0x030B0000
+_numpy_version = '>=1.16'
 
 def major(v):
     """Return the major component of version"""
@@ -112,22 +108,22 @@ def human_version(v):
     return f"{major(v)}.{minor(v)}"
 
 
-if sys.hexversion < minimal_version:
+if sys.hexversion < _minimal_version:
     # Older than minimal
     y = human_version(sys.hexversion)
-    m = human_version(minimal_version)
+    m = human_version(_minimal_version)
     raise RequirementsError(f"""
 Your Python version is {y}, but pyFormex requires Python >= {m}.
 We advice you to upgrade your Python version.
 """)
 
-if sys.hexversion & 0xFFFF0000 > target_version:
+if sys.hexversion & 0xFFFF0000 > _target_version:
     # Major,minor newer than target:
     y = human_version(sys.hexversion)
-    t = human_version(target_version)
+    t = human_version(_target_version)
     startup_warnings.append(f"""
-Your Python version is {y}, but pyFormex has only been tested
-with Python <= {t}. We expect pyFormex to run correctly with
+Your Python version is {y}, but {Version()} has only been tested
+with Python <= {t}. We expect {Version()} to run correctly with
 your Python version, but if you encounter problems, please
 contact the developers at http://pyformex.org.
 """)
@@ -234,11 +230,11 @@ libraries = ['misc_c', 'nurbs_c', 'clust_c']
 
 if installtype == 'G':
     # We are running from a source tree (Git)
+    import importlib.machinery
 
     def run_cmd(cmd):
         """Run command"""
         import subprocess
-        #print(f"COMMAND: {cmd}")
         P = subprocess.Popen(
             str(cmd), stdout=subprocess.PIPE, shell=True, universal_newlines=True
         )
@@ -326,9 +322,8 @@ logger.info(f"Installation type {installtype} at {pyformexdir}")
 
 ################ Special import mechanisms ##############
 
-find_module = importlib.util.find_spec
-
 def import_lazy(name):
+    import importlib.util
     spec = importlib.util.find_spec(name)
     loader = importlib.util.LazyLoader(spec.loader)
     spec.loader = loader
@@ -338,6 +333,7 @@ def import_lazy(name):
     return module
 
 def import_direct(file):
+    import importlib.util
     import tokenize
     file_path = tokenize.__file__
     module_name = tokenize.__name__
@@ -347,6 +343,7 @@ def import_direct(file):
     spec.loader.exec_module(module)
     return module
 
+
 ################ pyFormex global variables and functions ###############
 
 # The GUI parts
@@ -386,6 +383,7 @@ def print_err(*args, **kargs):
     file = kargs.pop('file', sys.stderr)
     print(*args, **kargs, file=file)
 
+
 warning = print_err
 error = print_err
 
