@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -28,13 +28,11 @@
 """Predefined geometries for a special purpose.
 
 This module contains some predefined special purpose geometries functions.
-You need to import this module in your scripts/apps to have access to its
-contents.
 
 Contents
 --------
 
-:class:`Axes`
+:func:`Axes`
     A geometrical representation of a coordinate system.
 
 :func:`Horse`
@@ -48,14 +46,11 @@ from pyformex.coordsys import CoordSys
 from pyformex.olist import List
 
 
-class Axes(List):
-
+def Axes(cs=None, *, size=1.0, psize=0.5, reverse=True,
+         color=['red', 'green', 'blue', 'cyan', 'magenta', 'yellow'],
+         linewidth=2, alpha=0.5, **kargs):
     """A geometry representing the three axes of a coordinate system.
 
-    This class is a subclass of :class:`List` and contains two :class:`Mesh`
-    instances: the lines along the axes and the triangles in the coordinate
-    planes.
-
     The default geometry consists of three colored lines of unit length
     along the positive directions of the axes of the coordinate system,
     and three colored triangles representing the coordinate planes.
@@ -82,52 +77,46 @@ class Axes(List):
     **kargs: keyword arguments
         Any extra keyword arguments will be added as attributes
         to the geometry.
+
+    Returns
+    -------
+    :class:`List`
+        A List containing two :class:`Mesh` instances: the lines along the axes
+        and the triangles in the coordinate planes.
+
     """
+    if cs is None:
+        cs = CoordSys()
+    if not isinstance(cs, CoordSys):
+        raise ValueError(
+            f"cs should be a CoordSys, got {type(cs)=},\n {cs=}")
+    coords = cs.points().reshape(4, 3)
 
-    def __init__(
-        self,
-        cs=None,
-        size=1.0,
-        psize=0.5,
-        reverse=True,
-        color=['red', 'green', 'blue', 'cyan', 'magenta', 'yellow'],
-        linewidth=2,
-        alpha=0.5,
-        **kargs
-    ):
-        """Initialize the AxesGeom"""
+    # Axes
+    lines = [[3, 0], [3, 1], [3, 2]]
+    M = Mesh(coords.scale(size, center=coords[3]), lines)
+    col = color[:3]
+    if reverse:
+        # Add negative axes
+        M = Mesh.concatenate([M, M.reflect(dir=[0, 1, 2], pos=coords[3])])
+        col = color[:6]
+    M.attrib(
+        color=col, lighting=False, opak=True, linewidth=linewidth, **kargs
+    )
+    L = [M]
 
-        if cs is None:
-            cs = CoordSys()
-        if not isinstance(cs, CoordSys):
-            raise ValueError("cs should be a CoordSys")
-        coords = cs.points().reshape(4, 3)
-
-        # Axes
-        lines = [[3, 0], [3, 1], [3, 2]]
-        M = Mesh(coords.scale(size, center=coords[3]), lines)
+    # Coord planes
+    if psize > 0.0:
+        planes = [[3, 1, 2], [3, 2, 0], [3, 0, 1]]
+        M = Mesh(coords.scale(size * psize, center=coords[3]), planes)
         col = color[:3]
-        if reverse:
-            # Add negative axes
-            M = Mesh.concatenate([M, M.reflect(dir=[0, 1, 2], pos=coords[3])])
-            col = color[:6]
+        bkcol = color[3:6] if reverse else col
         M.attrib(
-            color=col, lighting=False, opak=True, linewidth=linewidth, **kargs
+            color=col, bkcolor=bkcol, lighting=False, alpha=alpha, **kargs
         )
-        L = [M]
+        L.append(M)
 
-        # Coord planes
-        if psize > 0.0:
-            planes = [[3, 1, 2], [3, 2, 0], [3, 0, 1]]
-            M = Mesh(coords.scale(size * psize, center=coords[3]), planes)
-            col = color[:3]
-            bkcol = color[3:6] if reverse else col
-            M.attrib(
-                color=col, bkcolor=bkcol, lighting=False, alpha=alpha, **kargs
-            )
-            L.append(M)
-
-        List.__init__(self, L)
+    return List(L)
 
 
 def Horse():
