@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -237,11 +237,11 @@ def run_pytest(modules):
         print("Can not import pytest")
         pass
 
-    #warnings.filterwarnings("always", category=DeprecationWarning)
-    #warnings.filterwarnings("always", category=PendingDeprecationWarning)
+    # warnings.filterwarnings("always", category=DeprecationWarning)
+    # warnings.filterwarnings("always", category=PendingDeprecationWarning)
 
     testpath = pf.cfg['testdir']
-    #print(f"TESTPATH={testpath}")
+    # print(f"TESTPATH={testpath}")
     args = ['--maxfail=10', '-W', 'always::DeprecationWarning']
     if not modules:
         pytest.main(args + [testpath])
@@ -311,8 +311,13 @@ def run_doctest(modules):
 
     # Remove modules that we can not test:
     todo = [m for m in todo if 'vtk' not in m]
+
+    # Remove plugins.mesh_io if we do not have meshio
     if not software.Module.has('meshio'):
-        todo.remove('meshio')
+        m = 'plugins.mesh_io'
+        if m in todo:
+            todo.remove(m)
+
 
     pf.debug(f"Final list of modules to test: {todo}", pf.DEBUG.DOCTEST)
     # Now perform the tests
