@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -57,11 +57,28 @@ RGB values in 0..1 range and luminance.
 
 import numpy as np
 
-import pyformex as pf
 import pyformex.arraytools as at
 
-# TODO: This should become a Color class
 
+# TODO: this should be lazyloaded !
+X11_colors = {}
+
+def loadX11Colors(filename):
+    """Load the X11 colors"""
+    with open(filename) as f:
+        for line in f:
+            s = line.strip().split()
+            name = ''.join(s[3:]).lower()
+            try:
+                X11_colors[name] = tuple(int(i) for i in s[:3])
+            except Exception:
+                pass
+
+
+loadX11Colors("/etc/X11/rgb.txt")
+
+
+# TODO: This should become a Color class
 
 def GLcolor(color):
     """Convert a color to an OpenGL RGB color.
@@ -145,9 +162,9 @@ def GLcolor(color):
         if col in PF_colors:
             # string defined in PF_colors:
             return PF_colors[col]
-        elif col in pf.X11colors:
-            # str defined in pf.X11colors:
-            col = pf.X11colors[col]
+        elif col in X11_colors:
+            # str defined in X11_colors:
+            col = X11_colors[col]
         else:
             # Try conversion to QColor
             col = QtGui.QColor(col)
@@ -192,7 +209,6 @@ def QTcolor(color):
     return QtGui.QColor.fromRgbF(*GLcolor(color))
 
 
-# TODO: Should convert result to Int8 ?
 def RGBcolor(color):
     """Return an RGB (0-255) tuple for a color
 
@@ -382,7 +398,7 @@ Palette = {
     'default': palette,
     'dark': [c for c in palette if luminance(c) < 0.5],
     'light': [c for c in palette if luminance(c) > 0.5],
-    }
+}
 
 
 # End
