@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -207,9 +207,9 @@ class Connectivity(np.ndarray):
         # Get the pickled ndarray state (as a list, so we can change it)
         object_state = list(np.ndarray.__reduce__(self))
         # Define our own state with the extra attributes we added
-        subclass_state = (str(self.eltype), None)
+        extra_state = str(self.eltype) if self.eltype is not None else None
         # Store both in place of the original ndarray state
-        object_state[2] = (object_state[2], subclass_state)
+        object_state[2] = (object_state[2], extra_state)
         return tuple(object_state)
 
 
@@ -217,20 +217,12 @@ class Connectivity(np.ndarray):
         """Restore from pickled state"""
         # In __reduce__, we replaced ndarray's state with a tuple
         # of itself and our own state
-        try:
-            nd_state, own_state = state
-            np.ndarray.__setstate__(self, nd_state)
-            self.eltype, self.inv = own_state
-        except Exception:
-            try:
-                # try to read legacy pickle format, which did not save
-                # the element type (rev < 2360)
-                np.ndarray.__setstate__(self, state)
-                print("WARNING: Connectivity was restored without element type!")
-            except Exception:
-                print("I could not unpickle the Connectivity,"
-                      " neither in old nor new format")
-                raise
+        nd_state, extra_state = state
+        np.ndarray.__setstate__(self, nd_state)
+        if isinstance(extra_state, tuple):
+            extra_state = extra_state[0]  # legacy version stored (eltype,inv)
+        self.eltype = extra_state
+        self.__array_finalize__(self)
 
 
     def __repr__(self):
@@ -320,7 +312,7 @@ class Connectivity(np.ndarray):
 
     def report(self):
         """Format a Connectivity table"""
-        s = f"Connectivity {self.shape}, eltype={self/eltype}"
+        s = f"Connectivity {self.shape}, eltype={self.eltype}"
         return s + '\n' + np.ndarray.__str__(self)
 
 
