@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -1723,7 +1723,7 @@ Tri6 = ElementType(
 class Lagrange2D(ElementType):
     def __init__(self, dr, ds, name=None, **kargs):
         ndim = 2
-        degree = (dr,ds)
+        degree = (dr, ds)
         nplex = (dr+1)*(ds+1)
         if name is None:
             if dr == ds:
@@ -1762,12 +1762,7 @@ class Lagrange2D(ElementType):
 
     def wts(self, rdiv, sdiv=None):
         r = seeds(rdiv, self.dr)
-        nr = len(r)
-        if sdiv is None:
-            s, ns = r, nr
-        else:
-            s = seeds(sdiv, self.ds)
-            ns = len(s)
+        s = r if sdiv is None else seeds(sdiv, self.ds)
         r, s = np.meshgrid(r, s)
         H = np.stack([h(r,s) for h in self.h])
         return H.reshape((len(self.h), -1)).transpose()
@@ -2151,17 +2146,8 @@ class Lagrange3D(ElementType):
 
     def wts(self, rdiv, sdiv=None, tdiv=None):
         r = seeds(rdiv, self.dr)
-        nr = len(r)
-        if sdiv is None:
-            s, ns = r, nr
-        else:
-            s = seeds(sdiv, self.ds)
-            ns = len(s)
-        if tdiv is None:
-            t, nt = s, ns
-        else:
-            t = seeds(tdiv, self.dt)
-            nt = len(t)
+        s = r if sdiv is None else seeds(sdiv, self.ds)
+        t = s if tdiv is None else seeds(tdiv, self.dt)
         t, s, r = np.meshgrid(t, s, r, indexing='ij')
         H = np.stack([h(r,s,t) for h in self.h])
         return H.reshape((len(self.h), -1)).transpose()
