@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -47,7 +47,6 @@ During the second half, all texts remain on the canvas.
 """
 
 
-_status = 'checked'
 _level = 'normal'
 _topics = ['text']
 _techniques = ['color', 'random', 'animation']
@@ -81,6 +80,7 @@ def run():
 
 
     for i in range(n):
+        print(fonts[f[i]])
         TB = drawText(T[t[i]], a[i], font=fonts[f[i]], size=size[i],
                       color=list(colors[i]), rotate=rot[i])
         sleep(0.4)
