@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -33,7 +33,6 @@ scheme is to be used: no color (black), a single color, a single color per
 face, or a color gradient over the faces.
 """
 _name = 'Cube'
-_status = 'checked'
 _level = 'normal'
 _topics = ['geometry', 'surface']
 _techniques = ['color', 'elements', 'reverse']
