@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -31,7 +31,6 @@ displayed on a Formex grid and can be manipulated and transformed by
 the usual pyFormex methods.
 """
 
-_status = 'checked'
 _level = 'normal'
 _topics = ['text']
 _techniques = ['dialog', 'font', 'text']
@@ -53,6 +52,8 @@ def sameLength(text):
 def draw3DText(text, font=None, ftsize=10, color=None, texmode=2, ontop=True):
     if isinstance(text, str):
         text = text.split('\n')
+    if not isinstance(text, list):
+        raise ValueError(f"Expected a str or a list of str, got {type(text)=}")
     text = sameLength(text)
     nrows = len(text)
     ncols = len(text[0])
