@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -32,7 +32,6 @@ steel plate, how to add material properties, boundary conditions and loads,
 and how to export the resulting model as an input file for Abaqus(tm) or
 Calculix.
 """
-_status = 'checked'
 _level = 'advanced'
 _topics = ['FEA']
 _techniques = ['properties', 'export', 'extrude']
