@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -33,7 +33,6 @@ installed. On Debian GNU/Linux you can achieve this by installing the package
 
 """
 
-_status = 'checked'
 _level = 'advanced'
 _topics = ['curve', 'font']
 _techniques = ['bezier', 'borderfill']
@@ -81,12 +80,13 @@ try:
 
     def glyphCurve(c):
         """Convert a glyph contour to a list of quad bezier curves."""
+        print(c)
+        print([type(ci) for ci in c])
         points = []
         control = []
         P0 = c[0]
         points.append([P0.x, P0.y])
-        for i in (np.arange(len(c))+1) % len(c):
-            P = c[i]
+        for P in c:
             if P0.on_curve and P.on_curve:
                 # straight segment
                 control.append([0.5*(P0.x+P.x), 0.5*(P0.y+P.y)])
@@ -119,7 +119,6 @@ try:
         return Coords(points), Coords(control)
 
 
-
     def contourCurve(c):
         """Convert a fontforge contour to a pyFormex curve"""
         points, control = glyphCurve(c)
