@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -30,7 +30,6 @@
 Example demonstrating the components of input dialogs.
 """
 
-_status = 'checked'
 _level = 'normal'
 _topics = []
 _techniques = ['dialog']
@@ -122,7 +121,7 @@ input_tabgroup = [
     ]
 
 input_data = [
-    _T('Text', input_text[:3], width=600),
+    _T('Text', input_text, width=600),
     _T('Selection', input_select, width=600),
     _T('Numerical', input_numerical, width=600),
     _T('Special', input_special, width=600),
