@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -30,7 +30,6 @@ This example shows how to find out if points are inside a closed surface.
 
 """
 _name = 'Inside'
-_status = 'checked'
 _level = 'normal'
 _topics = ['surface', 'vtk']
 _techniques = ['inside', 'timer', 'multitask']
@@ -123,7 +122,7 @@ def testInside(S, P, method, atol, multi):
         ind = S.inside(P, method=method, tol=atol, multi=multi)
 
     print(f"{method}_inside: {P.shape[0]} points / {S.nelems()} faces:"
-          f" found {len(ind)} inside points in {t.lastread} seconds")
+          f" found {len(ind)} inside points in {t.mem:.6f} seconds")
 
     if len(ind) > 0:
         draw(P[ind], color=green, marksize=3, ontop=True, nolight=True, bbox='last')
