@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -37,9 +37,6 @@ pyFormex code.
 Later I added some nice utilities to make it worthwile as a programming example.
 It would be nice a nice exercise to add a GUI to create and position the shapes.
 """
-
-
-_status = 'checked'
 _level = 'normal'
 _topics = ['illustration']
 _techniques = ['animation']
@@ -47,21 +44,20 @@ _techniques = ['animation']
 from pyformex.gui.draw import *
 
 
+class Polygon(Mesh):
+    def __init__(self, coords, *args, **kargs):
+        super().__init__(coords, np.arange(len(coords)).reshape(1,-1),
+                         eltype='polygon')
+
 def circle(n=60):
-    a1 = 360./n
-    # we do not have the 'polygon' mode anymore!
-    #return Formex([[[cosd(i*a1), sind(i*a1), 0.] for i in range(n)]])
-    # therefore create all triangles
-    return Formex([[[0., 0.],
-                    [at.cosd(i*a1), at.sind(i*a1)],
-                    [at.cosd((i+1)*a1), at.sind((i+1)*a1)]]
-                   for i in range(n)])
+    X = Coords('1').rosette(n).reshape(-1,3)
+    return Polygon(X)
 
 def triangle():
-    return Formex([[[0., 0., 0.], [1., 0., 0.], [0.5, 0.5*sqrt(3.), 0.]]])
+    return Polygon([[0., 0., 0.], [1., 0., 0.], [0.5, 0.5*sqrt(3.), 0.]])
 
 def square():
-    return Formex([[[0., 0., 0.], [1., 0., 0.], [1., 1., 0.], [0., 1., 0.]]])
+    return Polygon(Coords('0123'))
 
 
 class Shape():
@@ -114,7 +110,7 @@ def run():
     wall = Shape('square', [80., 60.], [10., 0.], 'red')
     window = Shape('square', [10., 10.], [30., 30.], 'white')
     roof = Shape('triangle', [100., 40.], [0., 60.], 'green')
-    sun = Shape('circle', 10, [110., 80.], 'yellow')
+    sun = Shape('circle', 10, [110., 80.], 'orange')
 
     delay(0)
     window.draw()
@@ -125,7 +121,7 @@ def run():
 
     # lower the sun
     n = 100
-    delay(10./n)
+    delay(2./n)
     setDrawOptions({'bbox': None})
     with busyCursor():
         sun.hide()
