@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -32,7 +32,6 @@ This example demonstrates several ways to construct 3D geometry from a
 sweeping, extruding, revolving or connecting.
 """
 
-_status = 'checked'
 _level = 'normal'
 _topics = ['geometry', 'surface']
 _techniques = ['color', 'sweep', 'extrude', 'connect', 'revolve', 'timer']
@@ -89,7 +88,7 @@ def run():
     # layout(n,3)
     t = Timer(auto=True)
     for i, method in enumerate(methods):
-        with t.tag(f"Computing ({method})"):
+        with t.newtag(f"Computing ({method})"):
             if method == 'Sweep':
                 path = simple.line([0, 0, 0], [0, 0, l], el).toCurve()
                 Beam = Section.sweep(path, normal=[0., 0., 1.], upvector=[0., 1., 0.])
@@ -113,7 +112,7 @@ def run():
 
         # viewport(i)
         # smoothwire()
-        with t.tag("Drawing"):
+        with t.newtag("Drawing"):
             clear()
             draw(Beam.getBorderMesh(), name='Beam', color='red', linewidth=2)
         export({f'Beam_{method}': Beam})
