@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -33,12 +33,11 @@ The user can select an image file. A rectangular grid with corrersponding
 number of cells is constructed. The grid is shown with the colors from the
 image and can possibly be transformed to a sphere or a half sphere.
 
-.. note:
+.. note::
   This example is slow when using high resolution images.
 """
 
 
-_status = 'checked'
 _level = 'normal'
 _topics = ['image']
 _techniques = ['color', 'filename']
