@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -126,7 +126,7 @@ def readOFF(filename):
      [1. 1. 0.]
      [0. 1. 0.]]
     >>> print(poly.elems)
-    Varray (2, (3, 3))
+    Varray (nrows=2, width=3..3)
       [0 1 2]
       [2 3 0]
 
@@ -239,7 +239,7 @@ def readOBJ(filename):
      [1.  1.  0.]
      [0.  1.  0.]]
     >>> print(poly.elems)
-    Varray (1, (4, 4))
+    Varray (nrows=1, width=4..4)
       [0 1 2 3]
     """
     from pyformex.polygons import Polygons
@@ -332,7 +332,7 @@ def readPLY(filename, check=True):
      [1.  1.  0.]
      [0.  1.  0.]]
     >>> print(poly.elems)
-    Varray (1, (4, 4))
+    Varray (nrows=1, width=4..4)
       [0 1 2 3]
     >>> M = Mesh(eltype='quad4').convert('tri3-u')
     >>> writePLY(f, M, binary=True)
@@ -347,7 +347,7 @@ def readPLY(filename, check=True):
      [1. 1. 0.]
      [0. 1. 0.]]
     >>> print(P.elems)
-    Varray (2, (3, 3))
+    Varray (nrows=2, width=3..3)
       [0 1 2]
       [2 3 0]
     """
@@ -733,7 +733,7 @@ def stlConvert(stlname, outname=None, binary=False, options='-d'):
 
     if ftype in ['off', 'stl', 'stla', 'stlb']:
         utils.External.has('admesh')
-        cmdopt = {'off': '--write-off', 'stlb':'-b'}.get(ftype, '-a')
+        cmdopt = {'off': '--write-off', 'stlb': '-b'}.get(ftype, '-a')
         cmd = f"admesh {options} {cmdopt} '{outname}' '{stlname}'"
     elif ftype == 'gts':
         cmd = f"stl2gts < '{stlname}' > '{outname}'"
@@ -829,7 +829,7 @@ def convertInp(filename):
     """Convert an Abaqus .inp to a .mesh set of files"""
     filename = Path(filename).resolve()
     converter = pf.cfg['bindir'] / 'read_abq_inp.awk'
-    cmd = "cd {filename.parent}; awk -f {converter} {filename.name}"
+    cmd = f"cd {filename.parent}; awk -f {converter} {filename.name}"
     print(cmd)
     P = utils.command(cmd, shell=True)
     print(P.stdout)
