@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -217,7 +217,7 @@ def writeOFF(fn, coords, faces=None, *, name=None,
      [1. 1. 0.]
      [0. 1. 0.]]
     >>> print(P.elems)
-    Varray (3, (3, 4))
+    Varray (nrows=3, width=3..4)
       [0 1 4 5]
       [4 1 2]
       [2 3 4]
@@ -323,7 +323,7 @@ def writeOBJ(fn, coords, faces=None, *, edges=None, points=None,
      [1. 1. 0.]
      [0. 1. 0.]]
     >>> print(P.elems)
-    Varray (3, (3, 4))
+    Varray (nrows=3, width=3..4)
       [0 1 4 5]
       [4 1 2]
       [2 3 4]
@@ -444,7 +444,7 @@ def writePLY(fn, coords, faces=None, *, edges=None,
      [1. 1. 0.]
      [0. 1. 0.]]
     >>> print(P.elems)
-    Varray (3, (3, 4))
+    Varray (nrows=3, width=3..4)
       [0 1 4 5]
       [4 1 2]
       [2 3 4]
