@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -51,10 +51,11 @@ def _coords_property1(funcname):
     This is NOT a decorator function.
     It would be good to make it into a decorator though.
     """
-    doc = f"""Return the `{funcname}` property of the `coords` attribute of the Geometry object.
-
-    See :attr:`coords.Coords.{funcname}` for details.
-    """
+    doc = (
+        f"Return the `{funcname}` property of the `coords` attribute "
+        f"of the Geometry object.\n\n"
+        f"See :attr:`coords.Coords.{funcname}` for details."
+    )
     return property(lambda s: getattr(s.coords, funcname), doc=doc)
 
 def _coords_transform(func):
@@ -67,7 +68,8 @@ def _coords_transform(func):
     newf.__doc__ = (
         f"Apply the :class:`~coords.Coords.{func.__name__}` transformation "
         "to the Geometry object.\n\n"
-        f"See :meth:`coords.Coords.{func.__name__}` for details.")
+        f"See :meth:`coords.Coords.{func.__name__}` for details."
+    )
     return newf
 
 def _coords_method(func):
@@ -80,7 +82,8 @@ def _coords_method(func):
     newf.__doc__ = (
         f"Call Coords.{func.__name__} method "
         "on the Geometry object's coords.\n\n"
-        f"See :meth:`coords.Coords.{func.__name__}` for details.")
+        f"See :meth:`coords.Coords.{func.__name__}` for details."
+    )
     return newf
 
 
