@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -96,24 +96,4 @@ class QImage(QtGui.QImage):
         QtGui.QImage.__init__(self, *args)
 
 
-# Load X11 color names
-
-def loadX11Colors(filename):
-    """Load the X11 colors"""
-    x11colors = {}
-    with open(filename) as f:
-        for line in f:
-            s = line.strip().split()
-            name = ''.join(s[3:]).lower()
-            try:
-                x11colors[name] = tuple(int(i) for i in s[:3])
-            except Exception:
-                pass
-
-    return x11colors
-
-pf.X11colors = loadX11Colors("/etc/X11/rgb.txt")
-pf.X11 = len(pf.X11colors) > 0
-
-
 # End
