@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -62,12 +62,11 @@ def classify(appdir, pkg, nmax=0):
     """
     class failed():
         """A class to allow failing examples in the catalog"""
-        _status = 'failed'
+        pass
 
     all_apps = sorted(apps.detect(appdir))
-    kat = ['byname', 'status', 'level', 'topics', 'techniques']
+    kat = ['byname', 'level', 'topics', 'techniques']
     cat = dict([(k, set()) for k in kat])
-    cat['status'] = ['failed', 'checked', 'unchecked']
     cat['level'] = ['beginner', 'normal', 'advanced']
     print(cat)
     col = {}
@@ -98,7 +97,7 @@ def classify(appdir, pkg, nmax=0):
                     v = [vi.lower() for vi in v]
                 else:
                     v = v.lower()
-                if k in ['status', 'level']:
+                if k in ['level']:
                     v = [v]
                 else:
                     cat[k].update(v)
@@ -247,7 +246,7 @@ class AppMenu(menu.Menu):
 
     ::
 
-      AppMenu('History',files=["/my/script1.py","/some/other/script.pye"],\
+      AppMenu('History',files=["/my/script1.py","/some/other/script.py"],\
           mode='script',recursive=False)
 
     is typically used to create a history menu of previously visited script
