@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -698,7 +698,7 @@ class Gui(QtWidgets.QMainWindow):
             # script file
             label = 'Script:'
             name = Path(appname).name
-            self.canPlay = self.canEdit = utils.is_pyFormex(appname) or appname.endswith('.pye')
+            self.canPlay = self.canEdit = utils.is_pyFormex(appname)
 
         pf.prefcfg['curfile'] = appname
         #self.curfile.label.setText(label)
@@ -1330,6 +1330,7 @@ def createGUI():
     Qt wil remove the recognized Qt and X11 options.
     """
     pf.app = Application()
+    pf.X11 = pf.app.platformName() in ('xcb', )
 
     # Set OpenGL format and check if we have DRI
     qtgl.setOpenGLFormat()
