@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -339,21 +339,20 @@ if pf.installtype in 'UG':
         # ('dxfparser', (_E, 'dxfparser', 'pyformex-dxfparser')),  # fails
         ('postabq', (_E, 'postabq', 'pyformex-postabq')),
         ('gtsinside', (_E, 'gts', 'gtsinside')),
-        ]
+    ]
     dev_docs = [
-        ('Developer HOWTO', (_F, devdir / "HOWTO-dev.rst")),
-        ('pyFormex coding style guide', (_F, devdir / "HOWTO-style.rst")),
-        ('Installation of extra software', (_F, devdir / "install-extra.rst")),
-        ('Numpy documentation guidelines', (_U, 'https://numpydoc.readthedocs.io/en/latest/format.html#docstring-standard')),
-        ('re-structured text (reST)', (_U, 'http://docutils.sourceforge.io/rst.html')),
-        ]
-    dev_docs = [
-        ('Developer Guides', dev_docs),
-        # TODO: for some reason we need to specify the data=None argument
-        # otherwise Qt passes False to the function. Is this new?
-        # there may be other places where this fails. Set data=None by default?
+        ('Developer Guides',[
+            ('Developer HOWTO', (_F, devdir / "HOWTO-dev.rst")),
+            ('pyFormex coding style guide', (_F, devdir / "HOWTO-style.rst")),
+            ('Installation of extra software', (_F, devdir / "install-extra.rst")),
+            ('Numpy documentation guidelines', (_U, 'https://numpydoc.readthedocs.io/en/latest/format.html#docstring-standard')),
+            ('re-structured text (reST)', (_U, 'http://docutils.sourceforge.io/rst.html')),
+        ]),
         ('Build local documentation', buildHtmlDocs),
-        ]
+    ]
+else:
+    dev_installs = dev_docs = []
+
 
 ########## The help menu ##########
 
