@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -332,6 +332,7 @@ class PyConsole(QtWidgets.QWidget):
     fontsize: int
         The font size
     """
+    encoding = 'utf-8'
     # text colors
     COLOR_DEFAULT = None
     COLOR_INPUT = 'blue'     # command input
@@ -352,7 +353,7 @@ class PyConsole(QtWidgets.QWidget):
         self.content.setContentsMargins(0, 0, 0, 0)
         self.content.setSpacing(0)
 
-        # Display for output and stderr
+        # Display for stdout and stderr
         self.outdisplay = QtWidgets.QPlainTextEdit(self)
         self.outdisplay.setMaximumBlockCount(blockcount)
         self.outdisplay.setReadOnly(True)
@@ -419,7 +420,7 @@ class PyConsole(QtWidgets.QWidget):
         Parameters
         ----------
         filename: str
-            File name fir the saved output. Existing file will be overwritten.
+            File name for the saved output. Existing file will be overwritten.
         contents: str
             One of 'all', 'commands' or 'output'. The first character suffices.
             Determines what to write: all output, only commands, or only the
