@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -926,23 +926,26 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
                     X = o.coords[v]
                 elif isinstance(o, Mesh):
                     X = o.coords[o.elems[v]]
-                d = X.distanceFromPlane(self.camera.eye, -self.camera.axis)
-                j = d.argmin() // X.shape[1]
+                d = X.points().distanceFromPlane(
+                    self.camera.eye, -self.camera.axis)
+                j = d.argmin()
+                k = j // X.shape[1]
                 if imin < 0 or d[j] < dmin:
-                    imin, jmin, dmin = i, v[j], d[j]
+                    imin, jmin, dmin = i, v[k], d[j]
             picked.clear()
             picked.add([jmin], key=imin)
             picked.depth = dmin
 
 
     def filter_connected(self, picked, level=1):
-        """Narrow a Collection to the items connected or self.selection"""
+        """Narrow a Collection to the items connected to self.selection"""
         if not picked:
             return
         if not self.selection:
             # set to closest picked item
             self.selection = picked.copy()
             self.filter_closest(self.selection)
+            print(f"INITIAL SELECTION {self.selection}")
         imin = -1
         jmin = None
         dmin = None
@@ -1243,7 +1246,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.signals.CANCEL.disconnect(self.cancel_draw)
         self.drawmode = None
         # self.perspective(original_perspective)
-        # self.camera.unlock() # should unlock only if it wasn't lock
+        self.camera.unlock() # should unlock only if it wasn't locked before
 
     def accept_draw(self, clear=False):
         """Cancel an interactive drawing mode.
