@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -107,8 +107,8 @@ class Tensor(np.ndarray):
          [5. 4. 3.]]
 
     """
-
-    _contracted_order = [(0, 1, 2, 1, 2, 0), (0, 1, 2, 2, 0, 1)]
+    # this needs to be a tuple at least since numpy 1.24
+    _contracted_order = ((0, 1, 2, 1, 2, 0), (0, 1, 2, 2, 0, 1))
     _contracted_index = np.array([
         [0, 5, 4],
         [5, 1, 3],
@@ -129,7 +129,7 @@ class Tensor(np.ndarray):
         ar = data.view(clas)
         if cs is None:
             cs = CoordSys()
-        if not(isinstance(cs, CoordSys)):
+        if not isinstance(cs, CoordSys):
             raise ValueError('Wrong Coordinate System')
         ar.cs = cs
         return ar
@@ -251,10 +251,11 @@ class Tensor(np.ndarray):
 
         >>> t = Tensor([-19., 4.6, -8.3, 11.8, 6.45, -4.7 ])
         >>> p,a = t.principal()
-        >>> print(t.rotate(np.linalg.linalg.inv(a)))
+        >>> r = t.rotate(np.linalg.linalg.inv(a))
+        >>> print(r + 1.e-5)   # add a tol to avoid printing negative zeroes
         [[ 11.6178   0.       0.    ]
-         [ -0.      -9.0015  -0.    ]
-         [  0.      -0.     -25.3163]]
+         [  0.      -9.0015   0.    ]
+         [  0.       0.     -25.3163]]
         """
         rot = at.checkArray(rot, shape=(3, 3), kind='f')
         return Tensor(at.atba(rot, self), self.cs.rotate(rot))
