@@ -3,7 +3,7 @@
 //  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 //  SPDX-License-Identifier: GPL-3.0-or-later
 //
-//  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+//  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 //  pyFormex is a tool for generating, manipulating and transforming 3D
 //  geometrical models by sequences of mathematical operations.
 //  Home page: https://pyformex.org
@@ -38,7 +38,7 @@
 
 /****************** LIBRARY VERSION AND DOCSTRING *******************/
 
-static char *__version__ = "3.3";
+static char *__version__ = "3.4";
 static char *__doc__ = "\
 Miscellaneous accelerated low level functions.\n\
 \n\
@@ -1343,7 +1343,7 @@ static struct PyModuleDef moduledef = {
   NULL
 };
 
-PyObject *PyInit_misc_c(void)
+PyMODINIT_FUNC PyInit_misc_c(void)
 {
   PyObject* m;
   m = PyModule_Create(&moduledef);
