@@ -3,7 +3,7 @@
 //  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 //  SPDX-License-Identifier: GPL-3.0-or-later
 //
-//  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+//  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 //  pyFormex is a tool for generating, manipulating and transforming 3D
 //  geometrical models by sequences of mathematical operations.
 //  Home page: https://pyformex.org
@@ -41,7 +41,7 @@
 
 /****************** LIBRARY VERSION AND DOCSTRING *******************/
 
-static char *__version__ = "3.3";
+static char *__version__ = "3.4";
 static char *__doc__ = "Accelerated NURBS functions\n\
 \n\
 This module provides compiled C versions of the pyFormex low level\n\
@@ -72,13 +72,15 @@ int max(int a, int b)
 
 /* cumsum of a list of integer values */
 /* v and cs have same length */
-static void cumsum(int *v, int nv, int *cs)
+/* returns the total sum (the last element of cs) */
+int cumsum(int *v, int nv, int *cs)
 {
   int i, sum = 0;
   for (i=0; i<nv; ++i) {
     sum += v[i];
     cs[i] = sum;
   }
+  return cs[nv-1];
 }
 
 /* Dot product of two vectors of length n */
@@ -2425,11 +2427,7 @@ static PyObject * curveKnotRemove(PyObject *self, PyObject *args)
 
   /* Compute derived data as needed by curve_knot_remove */
   int *Sm = (int*) malloc(nv*sizeof(int));
-  cumsum(Um,nv,Sm);
-  /* printf("Cumsum: "); */
-  /* for (i=0; i<nv; ++i) printf("%d, ",Sm[i]); */
-  /* printf("\n"); */
-  nk = Sm[nv-1];
+  nk = cumsum(Um,nv,Sm);
   double *U = (double*) malloc(nk*sizeof(double));
   k = 0;
   for (i=0; i<nv; ++i)
