@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -79,10 +79,6 @@ warn_formex_eltype = "Formex eltype currently needs to be a string!"
 warn_inertia_changed = "The Coords.inertia method has changed: it now returns an inertia.Inertia class instance, with attributes mass, ctr, tensor, and method principal() returning (Iprin,Iaxes)."
 warn_inputcombo_onselect = "InputCombo: the use of onselect is deprecated. Use 'func' instead. It receives the InputItem as parameter."
 warn_Interaction_changed = "Class fe_abq.Interaction has been changed, only allowed parameters are name, friction, surfacebehavior, surfaceinteraction, extra (see doc)."
-lazy_deprecated = """\
-The deprecated lazy script mode has been removed. While you can still import the lazy module (and everything from it), it is better to fix your imports from numpy and pyformex.arraytools now and add a np. or at. prefix.
-The lazy module will be removed in future.
-"""
 
 warn_mesh_extrude = "Mesh.extrude parameters have changed. The signature is now  extrude(div,dir,length) where length is the total extrusion length."
 warn_mesh_connect = "Mesh.connect does no longer automatically compact the Meshes. You may have to use the Mesh.compact method to do so."
@@ -91,7 +87,6 @@ mesh_eltype = "Mesh.setEltype and Mesh.elType are deprecated. You can directly g
 warn_mesh_partitionbyangle = "The partitioning may be incorrect due to nonplanar 'quad4' elements"
 mesh_reduce_degenerate = "Mesh.reduceDegenerate has changed. It is now an alias for Mesh.splitDegenerate. See the docs."
 warn_mesh_reflect = "The Mesh.reflect will now by default reverse the elements after the reflection, since that is what the user will want in most cases. The extra reversal can be skipped by specifying 'reverse=False' in the argument list of the `reflect` operation."
-warn_multiplex_changed = "arraytools.multiplex has changed for negative values of the axis parameter. It now specifies the position of the new axis in the expanded array. This means that for negative values you should now specify a value that is one less than it was in the old behavior. Thus: -1 now means a new axis at the end. To avoid mistakes with the default value (which was -1), multiplex no longer has a default value for axis."
 
 warn_nurbs_curve = "Nurbs curves of degree > 7 can currently not be drawn! You can create some approximation by evaluating the curve at some points."
 warn_nurb_surface = "Nurbs surfaces of degree > 7 can currently not be drawn! You can approximate the surface by a lower order surface."
@@ -113,7 +108,6 @@ warn_radio_enabler = "A 'radio' type input item can currently not be used as an
 
 trisurface_remesh = "TriSurface.remesh now uses the instant-meshes program. If you don't have it, you can install if from the pyformex/extra/instant directory or from the Help menu"
 
-varray_width = "Varray.width now returns a tuple with the minimum and maximu width. Use maxwidth to get the old behavior."
 warn_viewport_linking = "Linking viewports is an experimental feature and is not fully functional yet."
 
 error_widgets_enableitem = "Error in a dialog item enabler. This should not happen! Please file a bug report."
