@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -32,22 +32,11 @@ in pyFormex in a unified way.
 
 """
 import multiprocessing as mp
-from multiprocessing import cpu_count  # noqa: F401 (imported from here)
 import numpy as np
 
-import pyformex as pf
 from pyformex.arraytools import splitar
 
-
-# def cpu_count():
-#     """Return the number of cpus that can actually be used.
-
-#     This may be different from os.cpu_count or multiprocessing.cpu_count,
-#     which both return the number of cpus in the system.
-#     """
-#     import os
-#     return len(os.sched_getaffinity(0))
-
+cpu_count = mp.cpu_count
 
 def splitArgs(args, mask=None, nproc=-1, close=False):
     """Split data blocks over multiple processors.
@@ -141,7 +130,7 @@ def dofunc(arg):
     return func(*args)
 
 
-def multitask(tasks, nproc=-1, _async=True):
+def multitask(tasks, nproc=-1):
     """Perform tasks in parallel.
 
     Runs a number of tasks in parallel over a number of subprocesses.
@@ -158,23 +147,6 @@ def multitask(tasks, nproc=-1, _async=True):
         processes than the number of tasks or the number of processing units
         available. The default will set ``nproc`` to the minimum of these two
         values.
-    _async: bool
-        If True (default), the tasks are executed asynchronously and the
-        results are collected when they are done. This has two benefits:
-
-        - multitask can be run in 'script' execution mode,
-        - the tasks can execute external commands (using :func:`process.run`,
-          not :func:`utils.system` or :func:`utils.command`).
-
-        If False, a small speedup may be obtained for tasks that do not
-        need _async=True. But since the gain is marginal, this is not made
-        the default. The use of this option is discouraged. It may be
-        removed in future.
-
-    Raises
-    ------
-    ValueError:
-        When using _async=False in script mode.
 
     Examples
     --------
@@ -184,27 +156,16 @@ def multitask(tasks, nproc=-1, _async=True):
     [5, 6]
     >>> from pyformex import process
     >>> tasks = [(process.run, ('ls -d .',)), (process.run, ('uname',))]
-    >>> for res in multitask(tasks, _async=True): print(res.stdout)
+    >>> for res in multitask(tasks): print(res.stdout)
     .
     Linux
-
     """
     if nproc < 0:
         nproc = min(len(tasks), mp.cpu_count())
-    pf.debug(f"Multiprocessing using {nproc} processors", pf.DEBUG.MULTI)
-
-    pool = mp.Pool(nproc)
-    if _async:
+    with mp.Pool(nproc) as pool:
         res = pool.map_async(dofunc, tasks)
         pool.close()
         pool.join()
         return res.get(timeout=10)
-    else:
-        if pf.scriptMode == 'script':
-            raise ValueError("_async=False can not be used in 'script' mode")
-        res = pool.map(dofunc, tasks)
-        pool.close()
-        return res
-
 
 # End
