@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -140,8 +140,8 @@ class Dict(defaultdict):
     - ``Dict(callable)``: an empty Dict with callable as default_factory
     - ``Dict(noncallable)``: a Dict without default_factory initialized with
       data fron noncallable (e.g. a dict or a sequence of tuples)
-    - ``Dict(callable,noncallable)``: a Dict with callable as default_factory
-      and initialized with data fron noncallable.
+    - ``Dict(callable, noncallable)``: a Dict with callable as default_factory
+      and initialized with data from noncallable.
 
     And since a Dict is callable, but a dict is not, Dict(some_dict) will
     initialize the data in the Dict, while Dict(some_Dict) will use
@@ -408,9 +408,8 @@ class CDict(Dict):
 
 returnNone = Dict.returnNone
 
-
-def __newobj__(cls, *args):
-    return cls.__new__(cls, *args)
+# def __newobj__(cls, *args):
+#     return cls.__new__(cls, *args)
 
 
 if __name__ == "__main__":
