@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -113,7 +113,7 @@ class FontTexture(Texture):
         except Exception:
             raise RuntimeError("Can not load font '%s' at size %s" % (filename, size))
         if not face.is_fixed_width:
-            raise RuntimeError("Font is not monospace")
+            raise RuntimeError(f"Font is not fixed width: {filename}")
 
         # Determine largest glyph size
         width, height, ascender, descender = 0, 0, 0, 0
