@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -26,17 +26,20 @@
 ##
 """Object oriented filesystem paths.
 
-This module defines the Path class providing object oriented handling
-of filesystem paths.
-It has many similarities to the classes in the :mod:`pathlib` module of
-Python3. But we had some good reasons to not use that module and create
-our own instead:
+This module defines the :class:`Path` class providing object oriented handling
+of filesystem paths. It was created for the pyFormex project
+(https://pyformex.org) but can be used independently from other pyFormex
+modules.
 
-- Python's pathlib is overly complex, with classes as Path, PosixPath,
+While our :class:`Path` class has many similarities to the classes in
+Python's :mod:`pathlib`, we we had some good reasons to not use that module
+and create our own instead:
+
+- Python's pathlib seemed overly complex, with classes as Path, PosixPath,
   WindowsPath, PurePath, PurePosixPath, PureWindowsPath. We just have one
   class (Path) that does it all.
 - Despite nearly all OSes implementing paths as strings, Python's
-  pathlib.Path is not a string (str), and this creates a lot of problems
+  pathlib.Path is not a string (str), and this created a lot of problems
   for transforming a program to the use of pathlib.Path. All file related
   functions and methods need to be changed to accept str as well as
   pathlib.Path as arguments.
@@ -49,17 +52,16 @@ our own instead:
   own Path class instead. Being a str, a Path can immediately be used in
   all places where a str is used, and all str methods can be applied on a
   Path.
-- We did not require compatibility with other OSes but Linux. Though the
+- We did not require compatibility with other OSes besides Linux. Though the
   class could likely be ported to other OSes with minor adjustments, the
   author never did consider doing it by lack of knowledge about Windows file
-  systems. (I know it's case insensitive, but that's about it).
-- Our Path class offers a lot more functionality than Python's, as we have
-  concentrated all path related code of pyFormex into this single module.
-  Clearly, this could help a lot in porting pyFormex to other OSes.
+  systems. But if anyone wants to try it, I'm willing to help.
+- Our Path class offers more functionality than Python's, as we have
+  collected all path related code from pyFormex into this single module.
 
 Despite the differences, there are also many similarities with
-the pathlib classes. We have tried as much as possible to use methods
-with the same name and functionality.
+the pathlib classes. We have tried to use as much as possible
+the same name and functionality for the class methods.
 
 Because we wanted this module to be of general use, the only dependencies
 are some Python standard library modules.
@@ -1142,7 +1144,7 @@ class Path(str):
                 if not re.fullmatch(pat, entry.name):
                     ok = False
             if ok:
-                yield(entry)
+                yield entry
 
     def iterdir(self, *args, **kargs):
         """Yield Path objects of the directory contents.
