@@ -1,9 +1,10 @@
+# flake8: noqa
 #
 ##
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -28,8 +29,8 @@
 """Vascular Sweeping Mesher
 
 """
+import numpy as np
 
-#from numpy import *
 from pyformex.trisurface import *
 from pyformex.core import *
 from pyformex.simple import *
