@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -32,7 +32,6 @@
 __all__ = ['splitFloat', 'readData']
 
 import re
-from numpy import *
 
 _re_float = re.compile(r'[-+]?(\d+(\.\d*)?|\.\d+)([eE][-+]?\d+)?')
 _re_float_string = re.compile(r'(?P<float>[-+]?(\d+(\.\d*)?|\.\d+)([eE][-+]?\d+)?)(?P<string>.*)')
@@ -124,7 +123,7 @@ def convertData(s, to):
 
 
 def readData(s, to, strict=False):
-    """Read values a string matching the units/type specifications.
+    """Read values from a string matching the units/type specifications.
 
     This is a powerful function for reading, interpreting and converting
     numerical data from a string.
@@ -177,61 +176,4 @@ def readData(s, to, strict=False):
     return [convertData(si, ti) for ti, si in zip(to, data)]
 
 
-###################################################
-## BV: The following functions need clean up
-## or should be replaced with a common module with calpy
-##
-
-
-def readAsciiTable(fn, header=True):
-    """_Reads data from an ASCII text file (Table).
-
-    if header is True: first line is the header, the rest is a table (2D array)
-    it returns the header and the 2D array of data as floats.
-    if header is False, there is no header.
-    it returns the header as None and the 2D array of data as floats.
-    """
-    fil=open(fn, 'r')
-    line = fil.readline()
-    h = line.strip('\n').split()
-    data = fromfile(fil, sep=' ', dtype=float32)
-    if header==False:
-        h=asarray(h, dtype=float)
-        data=append(h, data)
-        return None, data.reshape(-1, len(h))
-    if header==True:
-        data = data.reshape((-1, len(h)))
-    return h, data
-
-def writeAsciiTable(fn, h, d, fmtdata='e'):
-    """_Writes an ASCII text file.
-
-    The first line is the header h (tuple of strings, e.g. h=[ 'n0', 'n1', 'n2' ] ).
-    The other lines contains the data d (2D array of floats) as a table.
-    If format of the data can be chosen with fmtdata:
-        1) fmtdata is 'e' , the data are written as scientific (1.123456e+01),
-        2) fmtdata is 'f' , the data are written as floats,
-        3)fmtdata is 'd' , the data are written as integers,
-        4) otherwise, the fmt is specified (e.g. fmtdata='d f f d'). In this case, there should be as many fmt as data columns"""
-    fil=open(fn, 'w')
-    ncol= len(h)-1  # number of columns-1
-    fmtH = '%s'+ncol*' %s' + '\n'
-    fil.write(fmtH %(tuple(h)))  # header
-    if fmtdata is None: fmtdata='e'
-    if fmtdata=='e':
-        fmtD = '%e'+ncol*' %e' + '\n'
-    elif fmtdata=='f':
-        fmtD = '%f'+ncol*' %f' + '\n'
-    elif fmtdata=='d':
-        fmtD = '%d'+ncol*' %d' + '\n'
-    else:
-        dt= fmtdata.split(' ')
-        sdt='%'+dt[0]
-        for t in dt[1:]:
-            sdt=sdt+' %'+t
-        fmtD=sdt+'\n'
-    for ld in d:
-        fil.write(fmtD % (tuple(ld)))  # line of data
-    fil.close()
-
 # End
