@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -113,7 +113,7 @@ def gtsset(surf1, surf2, op, filt='', ext='', curve=False, check=False,
     -------
     TriSurface | dict | Mesh | None:
 
-        - if curve is False and op is one of '+', '-' or '\*': the resulting
+        - if curve is False and op is one of '+', '-' or '\\*': the resulting
           TriSurface;
         - if curve is False and op is 'a': a dict with four keys, each having
           a TriSurface as value:
@@ -287,7 +287,7 @@ def inside(surf, pts, atol='auto', multi=True, keep=False):
     bb = bboxIntersection(surf, pts)
     if bb.size == 0:
         # No bbox intersection: no points inside
-        return array([], dtype=Int)
+        return np.array([], dtype=at.Int)
 
     # Limit the points to the common part
     # Add point numbers as property, to allow return of original numbers
@@ -309,7 +309,7 @@ def inside(surf, pts, atol='auto', multi=True, keep=False):
             ins[i, ok] = True
     else:
         tasks = [(gtsinside, (surf, pts.coords, i)) for i in range(3)]
-        ind = multitask(tasks, 3, _async=True)
+        ind = multitask(tasks, 3)
         for i in range(3):
             ins[i, ind[i]] = True
 
