@@ -1,9 +1,9 @@
-#
+# flake8: noqa
 ##
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -31,7 +31,6 @@ Plugin menu with mesh operations.
 """
 
 import pyformex as pf
-from pyformex import timer
 from pyformex.gui import menu
 from pyformex.gui import draw as gs
 from pyformex.mesh import Mesh
@@ -279,7 +278,7 @@ def colorByFront():
         pf.app.processEvents()
         if res:
             selection.remember()
-            with timer.Timer() as t:
+            with Timer() as t:
                 ftype = res['front type']
                 nwidth = res['front width']
                 maxval = nwidth * res['number of colors']
@@ -291,7 +290,7 @@ def colorByFront():
                     p = S.frontWalk(level=1, maxval=maxval, startat=startat)
                 S.setProp(p//nwidth + firstprop)
             nprops = len(S.propSet())
-            print(f"Colored in {nprops} parts ({t.lastread} sec.")
+            print(f"Colored in {nprops} parts ({t.mem:.6f} sec.)")
             selection.draw()
 
 
@@ -299,10 +298,10 @@ def partitionByConnection():
     S = selection.check(single=True)
     if S:
         selection.remember()
-        with timer.Timer() as t:
+        with Timer() as t:
             S.prop = S.partitionByConnection()
         nprops = S.prop.max()+1
-        print("Partitioned in {nprops} parts ({t.lastread} sec.)")
+        print(f"Partitioned in {nprops} parts ({t.mem:.6f} sec.)")
         selection.draw()
 
 ################### menu #################
