@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -50,7 +50,7 @@ from pyformex.elements import Quad4
 from pyformex import curve
 from pyformex import utils
 
-_py2rst_order_ = [ 'NurbsCurve', 'NurbsSurface' ]   # for docs only
+_py2rst_order_ = ['NurbsCurve', 'NurbsSurface']   # for docs only
 
 ###########################################################################
 ##
@@ -618,7 +618,7 @@ class NurbsCurve(Geometry4):
     def __init__(self, control, degree=None, wts=None, knots=None,
                  blended=True, closed=False, wrap=True, norm_urange=True):
         Geometry4.__init__(self)
-        #self.closed = closed
+        # self.closed = closed
         nctrl = len(control)
         if knots is not None:
             if not isinstance(knots, KnotVector):
@@ -726,7 +726,6 @@ class NurbsCurve(Geometry4):
         p = self.degree
         # This is important for closed curves!
         return [self.knotu[p], self.knotu[-1-p]]
-        #return self.knotu[0], self.knotu[-1]
 
 
     def isClamped(self):
@@ -837,9 +836,9 @@ class NurbsCurve(Geometry4):
         pts = lib.nurbs.curvePoints(ctrl, knots, u)
         if np.isnan(pts).any():
             print("We got a NaN")
-            print('ctrl',ctrl)
-            print('knots',knots)
-            print('u',u)
+            print(f"{ctrl=}")
+            print(f"{knots=}")
+            print(f"{u=}")
             raise RuntimeError("Some error occurred during the evaluation "
                                "of the Nurbs curve")
         if pts.shape[-1] == 4:
@@ -1367,7 +1366,7 @@ class NurbsCurve(Geometry4):
         N = self
         while t > 0:
             from pyformex.lib import nurbs_e
-            #newP, newU, maxerr = lib.nurbs.curveDegreeReduce(N.coords, N.knots)
+            # newP, newU, maxerr = lib.nurbs.curveDegreeReduce(N.coords, N.knots)
             newP, newU, maxerr = nurbs_e.curveDegreeReduce(N.coords, N.knots, tol=tol)
             print(f"MAXERR = {maxerr}")
             N = NurbsCurve(newP, degree=self.degree-1, knots=newU,
@@ -1795,7 +1794,7 @@ class NurbsSurface(Geometry4):
 def besselTangents(Q, u):
     q = Q[1:] - Q[:-1]
     du = u[1:] - u[:-1]
-    d = q / du[:,np.newaxis]
+    d = q / du[:, np.newaxis]
     alfa = du[:-1] / (du[:-1] + du[1:])
     alfa = alfa[:, np.newaxis]
     D = np.empty(Q.shape)
@@ -1860,76 +1859,11 @@ def _compute_alpha(P30, T03):
     a = 16 - T03 @ T03
     b = 12 * P30 @ T03
     c = -36 * P30 @ P30
-    r1, r2, k = at.quadraticEquation(a,b,c)
+    r1, r2, k = at.quadraticEquation(a, b, c)
     assert (k!=2)
     return r2
 
 
-def cubicInterpolate(Q, T=None, return_param=False):
-    """Create a C1 cubic interpolation curve
-
-    Parameters
-    ----------
-    Q: :term:`coords_like` (npts, 3)
-        The points through which the curve should pass.
-    T: :term:`coords_like` (npts, 3), optional
-        The normalized tangent vectors at the points Q to a curve that
-        interpolates those points. If not provided, they are computed
-        with :func:`akimTangents`.
-    return_param: bool
-        If True, also returns also parameter values where the given points
-        occur.
-
-    Returns
-    -------
-    NurbsCurve:
-        A cubic NurbsCurve interpolating the points Q and having
-        tangents T at those points. The curve is
-        guaranteed to have C1 continuity (including in the speed of the
-        curve) and has a fairly uniform parametrization.
-    u: float array (npts, )
-        Only returned if return_param=True: the parametric values where
-        the input points are found on the NurbsCurve. Thus, N.pointsAt(u)
-        produces Q.
-
-    Notes
-    -----
-    Based on The NURBS Book 9.3.4.
-    """
-    Q = at.checkArray(Q, (-1,3), 'f')
-    d = curve.PolyLine(Q).lengths()
-    if (d==0.0).any():
-        raise ValueError("Double points in the data set are not allowed")
-    if T is None:
-        T = akimTangents(Q)
-    else:
-        T = at.checkArray(T, Q.shape, 'f')
-        T = at.normalize(T)
-    nQ = Q.shape[0]
-    P = np.zeros((2*nQ, 3), dtype=Q.dtype)
-    u = np.empty((nQ,), dtype=Q.dtype)
-    u[0] = 0
-    P[0] = Q[0]
-    P[-1] = Q[-1]
-    for i in range(1, nQ):
-        alpha = _compute_alpha(Q[i]-Q[i-1], T[i-1]+T[i])
-        P1 = Q[i-1] + alpha/3 * T[i-1]
-        P2 = Q[i] - alpha/3 * T[i]
-        P[2*i-1:2*i+1] = P1, P2
-        u[i] = u[i-1] + 3*at.length(P1 - Q[i-1])
-    u /= u[-1]
-    U = np.empty((2*nQ+4,), dtype=Q.dtype)
-    U[:4] = 0
-    U[-4:] = 1
-    U[4:-4:2] = u[1:-1]
-    U[5:-4:2] = u[1:-1]
-    N = NurbsCurve(P, knots=U, degree=3)
-    if return_param:
-        return N, u
-    else:
-        return N
-
-
 # TODO: we could add a T0/T1 option
 def cubicInterpolate(Q, T=None, return_param=False):
     """Create a C1 cubic interpolation curve
@@ -1962,7 +1896,7 @@ def cubicInterpolate(Q, T=None, return_param=False):
     -----
     Based on The NURBS Book 9.3.4.
     """
-    Q = at.checkArray(Q, (-1,3), 'f')
+    Q = at.checkArray(Q, (-1, 3), 'f')
     d = curve.PolyLine(Q).lengths()
     if (d==0.0).any():
         raise ValueError("Double points in the data set are not allowed")
@@ -2036,7 +1970,7 @@ def quadraticInterpolate(Q, T=None, corners=False, reduce=True,
     -----
     Based on The NURBS Book 9.3.2
     """
-    Q = at.checkArray(Q, (-1,3), 'f', 'i')
+    Q = at.checkArray(Q, (-1, 3), 'f', 'i')
     d = curve.PolyLine(Q).lengths()
     if (d==0.0).any():
         raise ValueError("Double points in the data set are not allowed")
@@ -2049,7 +1983,7 @@ def quadraticInterpolate(Q, T=None, corners=False, reduce=True,
     Q1, T1 = Q[1:], T[1:]
     t0, t1 = gt.intersectLineWithLine(
         Q0, T0, Q1, T1, mode='pair', times=True)
-    R = 0.5 * (Q0 + t0[:,np.newaxis]*T0 + Q1 + t1[:,np.newaxis]*T1)
+    R = 0.5 * (Q0 + t0[:, np.newaxis]*T0 + Q1 + t1[:, np.newaxis]*T1)
     nc = len(Q)
     newQ = []
     newR = []
@@ -2100,7 +2034,7 @@ def quadraticInterpolate(Q, T=None, corners=False, reduce=True,
         for k in range(2, nc):
             u[k] = u[k-1] + (u[k-1] - u[k-2]) * l1[k-1] / l2[k-2]
         u /= u[-1]
-        U = np.concatenate([[0,0],u,[1,1]])
+        U = np.concatenate([[0, 0], u, [1, 1]])
         Q = Coords.concatenate([Q[:1], R, Q[-1:]])
     else:
         # keep oncurve and intermediate points
@@ -2235,10 +2169,12 @@ def cubicSpline(Q, D0, D1, *, u=None, exp=0.7, return_param=False):
     globalInterpolationCurve: global interpolation curve of any degree
 
     """
+    Q = at.checkArray(Q, (-1, 3), 'f')
     # set the parameter values
     if u is None:
         u = globalInterpolationParameters(Q, exp=exp)
     else:
+        npts = Q.shape[0]
         u = at.checkArray(u, (npts,), 'f', 'i')
     # end conditions
     D0 = at.checkArray(D0, (3,), 'f', 'i')
@@ -2311,8 +2247,8 @@ def globalInterpolationCurve(Q, degree=3, *, D=None, D0=None, D1=None,
     cubicSpline: returns the classical C2 spline interpolate
     """
     p = degree
-    Q = at.checkArray(Q, (-1,3), 'f')
-    nQ = Q.shape[0]
+    Q = at.checkArray(Q, (-1, 3), 'f')
+    npts = Q.shape[0]
     if D is not None:
         D = at.checkArray(D, Q.shape, 'f')
         D0 = D1 = None
@@ -2339,10 +2275,10 @@ def globalInterpolationCurve(Q, degree=3, *, D=None, D0=None, D1=None,
         U, A = lib.nurbs.curveGlobalInterpolationMatrix(u, degree, it0, it1)
         # set right hand side (TODO: move this inside ^^^)
         if it0:
-            D0 = Coords(D0).reshape(-1,3) * U[p+1] / p * 4
+            D0 = Coords(D0).reshape(-1, 3) * U[p+1] / p * 4
             Q = Coords.concatenate([Q[0:1], D0, Q[1:]])
         if it1:
-            D1 = Coords(D1).reshape(-1,3) * (1-U[-(p+2)]) / p * 4
+            D1 = Coords(D1).reshape(-1, 3) * (1-U[-(p+2)]) / p * 4
             Q = Coords.concatenate([Q[:-1], D1, Q[-1:]])
     P = np.linalg.solve(A, Q)
     N = NurbsCurve(P, knots=U, degree=degree)
@@ -2485,7 +2421,8 @@ def lsqCurve(Q, p, nctrl, Wq=None, D=None, I=None, Wd=None, return_param=False):
     A = np.zeros((mc+1,))
     M = np.zeros((mc+1, nctrl))
     j = 0  # current index into I
-    mu2 = 0; mc2 = 0   # counters up to mu and mc
+    mu2 = 0
+    mc2 = 0   # counters up to mu and mc
     for i in range(npts):
         span = find_span(U, u[i], p, nctrl-1)
         dflag = j < nder and i == I[j]
@@ -2527,10 +2464,10 @@ def lsqCurve(Q, p, nctrl, Wq=None, D=None, I=None, Wd=None, return_param=False):
     lu, piv = linalg.lu_factor(NTWN)
     if mc < 0:
         # No constraints: direct solution
-        P = linalg.lu_solve((lu,piv), NTWS)
+        P = linalg.lu_solve((lu, piv), NTWS)
     else:
         # inverse of NTWN
-        NTWNI = linalg.lu_solve((lu,piv), np.identity(NTWN.shape[0]))
+        NTWNI = linalg.lu_solve((lu, piv), np.identity(NTWN.shape[0]))
         # Solve for Lagrange multipliers: Nurbsbook  eq 9.75
         MI = M @ NTWNI
         MIMT = MI @ M.T
@@ -2581,10 +2518,10 @@ def optLsqCurve(Q, p, dtol, nmin=None, nmax=None):
     npts = Q.shape[0]
     nmax = npts-1 if nmax is None else min(nmax, npts-1)
     nmin = p+1 if nmin is None else max(nmin, p+1)
-    N, dmin = _one_step(Q,p,nmin)
+    N, dmin = _one_step(Q, p, nmin)
     if dmin < dtol:
         return N, dmin
-    Nmax, dmax = _one_step(Q,p,nmax)
+    Nmax, dmax = _one_step(Q, p, nmax)
     if dmax > dtol:
         raise ValueError(f"No solution with nmax={nmax} and dtol={dtol}; "
                          f"smallest dtol is {dmax}")
@@ -2593,7 +2530,7 @@ def optLsqCurve(Q, p, dtol, nmin=None, nmax=None):
     while nmin < nmax-1 and it < maxit:
         nr = (nmin*(dtol-dmax) + nmax*(dmin-dtol)) / (dmin-dmax)
         n = int(round(nr))
-        N, d = _one_step(Q,p,n)
+        N, d = _one_step(Q, p, n)
         if d < dtol:
             if n == nmax:
                 break
