@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -33,10 +33,10 @@ This is a support module for other pyFormex plugins.
 from copy import deepcopy
 
 import pyformex as pf
-from pyformex import geomfile
-from pyformex.coords import bbox
+from pyformex import fileread
+from pyformex import filewrite
 from pyformex.gui import draw as gs
-from pyformex.gui.draw import _I, _G, _C, _T
+from pyformex.gui.draw import _I
 
 
 class Objects():
@@ -295,10 +295,10 @@ class Objects():
             pf.warning(f"There are no objects of class {allowed.__name__}")
             return None
         res = gs.selectItems(caption=f"Known objects of type {self.object_type}",
-                          choices=choices,
-                          default=[n for n in self.names if n in choices],
-                          single=single,
-                          sort=True)
+                             choices=choices,
+                             default=[n for n in self.names if n in choices],
+                             single=single,
+                             sort=True)
         if res is None:
             res = []
         self.set(res)
@@ -325,7 +325,7 @@ class Objects():
 
     def keep(self):
         """Remove everything except the selection from the globals."""
-        gs.forget([n for n in self.listAll() if not n in self.names])
+        gs.forget([n for n in self.listAll() if n not in self.names])
 
 
     def writeToFile(self, filename):
@@ -482,7 +482,7 @@ class DrawableObjects(Objects):
         for f in self._annotations.values():
             if ontop in [True, False, '']:
                 if not isinstance(f, list):
-                   f = [f]
+                    f = [f]
                 for a in f:
                     if ontop == '':
                         ontop = not a.ontop
@@ -501,7 +501,7 @@ class DrawableObjects(Objects):
         objects = self.check()
         if objects:
             if prop is None:
-                res = gs.askItems(caption = 'Set Property Value', items=[
+                res = gs.askItems(caption='Set Property Value', items=[
                     _I('method', choices=['single', 'list', 'object',
                                           'element', 'none']),
                     _I('value', 0,
