@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -33,9 +33,9 @@ This is a plugin for pyFormex.
 See the Section2D example for an example of its use.
 """
 
+import numpy as np
 
 from pyformex.plugins import sectionize
-from numpy import *
 
 ## initialization should be with a closed PolyLine, after checking it is plane
 
@@ -108,7 +108,7 @@ def sectionChar(F):
     y1 = y[:, 1]
     a = (x0*y1 - x1*y0) / 2
     return {
-        'L': sqrt((x1-x0)**2 + (y1-y0)**2).sum(),
+        'L': np.sqrt((x1-x0)**2 + (y1-y0)**2).sum(),
         'A': a.sum(),
         'Sx': (a*(y0+y1)).sum()/3,
         'Sy': (a*(x0+x1)).sum()/3,
@@ -159,13 +159,12 @@ def princTensor2D(Ixx, Iyy, Ixy):
     - `alpha` : angle (in radians) from x-axis to principal X-axis
     - `IXX,IYY` : principal values of the tensor
     """
-    from math import sqrt, atan2
     C = (Ixx+Iyy) * 0.5
     D = (Ixx-Iyy) * 0.5
-    R = sqrt(D**2 + Ixy**2)
+    R = np.sqrt(D**2 + Ixy**2)
     IXX = C+R
     IYY = C-R
-    alpha = atan2(Ixy, D) * 0.5
+    alpha = np.arctan2(Ixy, D) * 0.5
     return alpha, IXX, IYY
 
 
