@@ -1,9 +1,9 @@
-#
+# flake8: noqa
 ##
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -31,7 +31,6 @@ Surface operations plugin menu for pyFormex.
 """
 
 import pyformex as pf
-from pyformex import timer
 from pyformex.gui import menu
 from pyformex.plugins import plot2d
 from pyformex.plugins import fe_abq
@@ -384,11 +383,11 @@ def partitionByAngle():
         pf.app.processEvents()
         if res:
             selection.remember()
-            with timer.Timer() as t:
+            with Timer() as t:
                 p = S.partitionByAngle(angle=res['angle'], sort=res['sort by'])
                 S = S.setProp(p + res['firstprop'])
             nprops = len(S.propSet())
-            print(f"Partitioned in {nprops} parts ({t.lastread} sec.)")
+            print(f"Partitioned in {nprops} parts ({t.mem:.6f} sec.)")
             for p in S.propSet():
                 print(" p: %s; n: %s" % (p, (S.prop==p).sum()))
             selection.draw()
@@ -603,7 +602,7 @@ def slicer():
         axis = res['Direction']
         nslices = res['# slices']
         with busyCursor():
-            with timer.Timer("Sliced", auto=True):
+            with Timer("Sliced", auto=True):
                 slices = S.slice(dir=axis, nplanes=nslices)
         print([s.nelems() for s in slices])
         draw([s for s in slices if s.nelems() > 0], color='red',
@@ -1020,10 +1019,10 @@ def remesh():
             if k != res['resolution']:
                 res.pop(k, None)
         res.pop('resolution', None)
-        with timer.Timer('Remeshing') as t:
+        with Timer('Remeshing') as t:
             mesh = S.remesh(**res)
         if mesh:
-            pf.verbose(2, f"Converted {name} to {mesh.elName()} Mesh named {qname} in {t.lastread} sec.")
+            pf.verbose(2, f"Converted {name} to {mesh.elName()} Mesh named {qname} in {t.mem:.6f} sec.")
             pf.verbose(2, mesh)
             export({qname:mesh})
             pf.GUI.selection['geometry'].set([qname])
