@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -34,6 +34,7 @@ these tools can be invoked from the Tools menu.
 import pyformex as pf
 from pyformex.core import np, at, gt, utils, Coords, Formex, Mesh, TriSurface
 from pyformex.collection import Collection
+from pyformex.curve import PolyLine
 from pyformex.gui import draw as gs
 from pyformex.gui.draw import _T, _I
 
@@ -268,7 +269,7 @@ class Labels:
         add: add a Label to the Labels collection
         addLabel: create a Label and add it to the collection
         """
-        point = Coords(point).reshape(1,3)
+        point = Coords(point).reshape(1, 3)
         text = self.gentext() if text is None else str(text)
         color = self.gencolor() if color is None else int(color)
         return Label(point, text, color)
@@ -399,9 +400,11 @@ def labelPoints(labels=None, gentext=None, edit=False):
     def modify_labels(self):
         from pyformex.gui.qtcanvas import _PICK_SET, _PICK_ADD, _PICK_REMOVE
         nonlocal labels
+
         def remove(b):
             labels.removeLabel(label)
             b.parent().parent.reject()
+
         xactions = [('Remove', remove)]
         self.highlightSelection(self.picked)
         points = getPoints(self.picked)
@@ -425,7 +428,7 @@ def labelPoints(labels=None, gentext=None, edit=False):
     def label_points_func(self):
         nonlocal labels
         self.selection.keep_order = True  # TODO:this should be an option of pick
-        #self.modify_selection()
+        # self.modify_selection()
         modify_labels(self)
         print("Current labels:", labels, sep='\n')
 
@@ -447,7 +450,7 @@ def label_dist2D(P, Q, prec):
     return f" dist={at.length(PQ[:2]):{prec}} ({PQ.x:{prec}}, {PQ.y:{prec}})"
 
 def label_angle2D(P, Q, R, prec):
-    angle = gt.rotationAngle(R-Q, P-Q, m=(0.,0.,1.), angle_spec=at.DEG)[0]
+    angle = gt.rotationAngle(R-Q, P-Q, m=(0., 0., 1.), angle_spec=at.DEG)[0]
     print(angle)
     return f" angle={angle:{prec}}"
 
@@ -456,7 +459,7 @@ def labelPoints2D(query='point', *,
                   surface=None, missing='r', zvalue=None, npoints=-1,
                   labels=None, gravity='e', drawstyle=2, linewidth=2,
                   prec='+.4f', labeltext=None,
-#                  every=1, keeplines=False
+                  # every=1, keeplines=False
                   ):
     """Interactively create and label points on a plane or a surface.
 
@@ -564,7 +567,7 @@ def labelPoints2D(query='point', *,
             'coords': label_coords2D,
             'dist': label_dist2D,
             'angle': label_angle2D,
-            }[query]
+        }[query]
     if query != 'coords':
         drawstyle = 0
 
@@ -574,9 +577,9 @@ def labelPoints2D(query='point', *,
         PP = P.toCS(cs)
         QQ = Q.toCS(cs)
         RR = Coords([QQ.x, PP.y, 0.])
-        #SS = Coords([QQ.x, QQ.y, 0.])
+        # SS = Coords([QQ.x, QQ.y, 0.])
         R = RR.fromCS(cs)
-        #S = SS.fromCS(cs)
+        # S = SS.fromCS(cs)
         if abs(style) == 1:
             F = Formex([[P, Q]]).setProp(color)
         elif abs(style) == 2:
@@ -584,7 +587,7 @@ def labelPoints2D(query='point', *,
         elif abs(style) == 3:
             F = PolyLine([P, (Q.x, P.y, P.z), (Q.x, Q.y, P.z), Q]).setProp(color)
         A = gs.draw(F, color='prop', linewidth=linewidth, ontop=True)
-        #labels.actors.append(A)
+        # labels.actors.append(A)
         return A
 
     def add_point(self):
@@ -602,7 +605,7 @@ def labelPoints2D(query='point', *,
                 connectPoints(cs.o, P, drawstyle)
             PP = P.toCS(cs)
             text = None if labeltext is None else labeltext(PP, prec)
-            label = labels.addLabel(P, text=text, color=color)
+            labels.addLabel(P, text=text, color=color)
             color += 1
         else:
             if query == 'dist' and len(self.drawing) % 2 == 0:
@@ -610,14 +613,14 @@ def labelPoints2D(query='point', *,
                 drawn.append(connectPoints(P, Q))
                 PP, QQ = P.toCS(cs), Q.toCS(cs)
                 text = labeltext(PP, QQ, prec)
-                label = labels.addLabel(0.5*(P+Q), text=text, color=color)
+                labels.addLabel(0.5*(P+Q), text=text, color=color)
                 color += 1
             elif query == 'angle' and len(self.drawing) % 3 == 0:
                 P, Q, R = self.drawing[-3:]
                 drawn.extend([connectPoints(P, Q), connectPoints(Q, R)])
                 PP, QQ, RR = P.toCS(cs), Q.toCS(cs), R.toCS(cs)
                 text = labeltext(PP, QQ, RR, prec)
-                label = labels.addLabel(Q, text=text, color=color)
+                labels.addLabel(Q, text=text, color=color)
                 color += 1
 
 
