@@ -1,9 +1,9 @@
-#
+# flake8: noqa
 ##
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -27,9 +27,8 @@
 """Wrl
 
 """
+import numpy as np
 
-
-from numpy import *
 from pyformex.gui.draw import *
 
 _prop_ = 0
@@ -48,7 +47,7 @@ def position(*args):
 def IndexedFaceSet(coords, faces=None):
     global _prop_
     _prop_ += 1
-    coords = asarray(coords).reshape(-1, 3)
+    coords = np.asarray(coords).reshape(-1, 3)
     print(coords.shape, _prop_)
     F = Formex(coords, _prop_)
     print(F.prop)
@@ -59,7 +58,7 @@ def IndexedFaceSet(coords, faces=None):
 
 
 def IndexedLineSet(coords, lines):
-    coords = asarray(coords).reshape(-1, 3)
+    coords = np.asarray(coords).reshape(-1, 3)
     print(coords.shape)
     F = Formex(coords, _prop_)
     draw(F)
