@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -97,7 +97,7 @@ class Polygons(Geometry):
                [1. 0. 0.]
                [1. 1. 0.]
                [0. 1. 0.]]
-      Elems: Varray (2, (3, 4))
+      Elems: Varray (nrows=2, width=3..4)
                [0 1 2]
                [0 1 2 3]
 
@@ -793,7 +793,7 @@ class Polygons(Geometry):
         [2. 1. 0.]
         [1. 1. 0.]]
         >>> print(P.elems)
-        Varray (3, (3, 4))
+        Varray (nrows=3, width=3..4)
           [0 1 2 3]
           [4 5 6]
           [4 6 7]
@@ -806,7 +806,7 @@ class Polygons(Geometry):
          [2. 0. 0.]
          [2. 1. 0.]]
         >>> print(P.elems)
-        Varray (3, (3, 4))
+        Varray (nrows=3, width=3..4)
           [0 2 3 1]
           [2 4 5]
           [2 5 3]
@@ -893,7 +893,7 @@ class Polygons(Geometry):
          [2. 0. 0.]
          [3. 0. 0.]]
         >>> print(P1.elems)
-        Varray (2, (3, 4))
+        Varray (nrows=2, width=3..4)
           [0 1 2]
           [2 3 1 0]
         >>> P1 is P
@@ -909,7 +909,7 @@ class Polygons(Geometry):
          [3. 0. 0.]
          [4. 0. 0.]]
         >>> print(P.elems)
-        Varray (2, (3, 4))
+        Varray (nrows=2, width=3..4)
           [3 0 1]
           [1 2 0 3]
         >>> print(P.oldnumbers)
@@ -997,13 +997,13 @@ class Polygons(Geometry):
         >>> x = Coords([[i] for i in np.arange(5)])
         >>> P = Polygons(x, [[0,1,2],[0,1,2,3],[0,1,2,3,4]])
         >>> print(P.reduce(4).elems)
-        Varray (4, (3, 4))
+        Varray (nrows=4, width=3..4)
           [0 1 2]
           [0 1 2]
           [0 1 2 3]
           [2 3 4 0]
         >>> print(P.reduce(3).elems)
-        Varray (6, (3, 3))
+        Varray (nrows=6, width=3..3)
           [0 1 2]
           [0 1 2]
           [0 1 2]
