@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -35,7 +35,6 @@ module.
 import os
 import sys
 import time
-import shutil
 
 import pyformex as pf
 from pyformex import utils
@@ -52,6 +51,8 @@ class _Exit(Exception):
     pass
 
 
+_script_timer = Timer('_script_')
+
 ############################# Globals for scripts ############################
 
 
@@ -251,7 +252,6 @@ def showInfo(message):
 ########################### PLAYING SCRIPTS ##############################
 
 exitrequested = False
-starttime = 0.0
 scriptInit = None  # can be set to execute something before each script
 
 
@@ -283,11 +283,9 @@ def playScript(scr, name=None, filename=None, argv=[], encoding=None):
         execution. This is mostly intended to obfuscate the code for
         occasional viewer.
     """
-    global starttime
     global exitrequested
 
-    # (We only allow one script executing at a time!)
-    # and scripts are non-reentrant
+    # Scripts are not reentrant, so we only allow one running at a time!
     if len(pf.scriptlock) > 0:
         print("!!Not executing because a script lock has been set: "
               f"{pf.scriptlock}")
@@ -299,24 +297,13 @@ def playScript(scr, name=None, filename=None, argv=[], encoding=None):
     if pf.GUI:
         pf.GUI.startRun()
 
-    # # Read the script, if a file was specified
-    # if not isinstance(scr, str):
-    #     # scr should be an open file/stream
-    #     if filename is None:
-    #         filename = scr.name
-    #     scr = scr.read() + '\n'
-
     # Get the globals
     g = Globals()
     if filename:
         g.update({'__file__': filename})
     g.update({'_argv_': argv})
 
-    # TODO: Should we continue support for this?
-    if encoding=='pye':
-        n = (len(scr)+1) // 2
-        scr = utils.mergeme(scr[:n], scr[n:])
-    elif encoding=='egg':
+    if encoding=='egg':
         import base64
         scr = base64.b64decode(scr)
 
@@ -336,8 +323,6 @@ def playScript(scr, name=None, filename=None, argv=[], encoding=None):
         filename = '<string>'
 
     # Execute the code
-    # TODO: Can we use a Timer() here?
-    starttime = time.perf_counter()
     try:
         pf.interpreter.locals.update(g)
         pf.interpreter.runsource(scr, str(filename), 'exec')
@@ -404,12 +389,10 @@ def runScript(fn, argv=[]):
         print(msg)
     pf.debug(f"  Executing with arguments: {argv}", pf.DEBUG.SCRIPT)
     encoding = None
-    if fn.suffix == '.pye':
-        encoding = 'pye'
 
-    with Timer() as t:
+    with _script_timer:
         res = playScript(fn.read_text(), fn, fn, argv, encoding)
-    msg = f"Finished script {fn} in {t.lastread} seconds"
+    msg = f"Finished script {fn} in {_script_timer.mem:.6f} seconds"
     if pf.GUI:
         pf.GUI.console.write(msg+'\n', color='red')
     else:
@@ -522,12 +505,13 @@ def runApp(appname, argv=[], refresh=False, lock=True, check=True, wait=False):
     app._argv_ = argv
     try:
         try:
-            with Timer() as t:
+            with _script_timer:
                 res = app.run()
         except SystemExit:
             print("EXIT FROM APP")
+            # TODO: this can be removed?
             pass
-        except Exception:
+        except Exception:  # TODO: this can be removed?
             raise
     finally:
         if hasattr(app, 'atExit'):
@@ -540,7 +524,7 @@ def runApp(appname, argv=[], refresh=False, lock=True, check=True, wait=False):
         if pf.GUI:
             pf.GUI.stopRun()
     pf.debug(f"  Arguments left after execution: {argv}", pf.DEBUG.SCRIPT)
-    msg = f"Finished {appname} in {t.lastread} seconds"
+    msg = f"Finished {appname} in {_script_timer.mem:.6f} seconds"
     if pf.GUI:
         pf.GUI.console.write(msg+'\n', color='green')
     else:
@@ -734,12 +718,12 @@ def processArgs(args):
             # next arg is a script
             txt = args.pop(0)
         if '++' in args:
+            # this is experimental and not documented
             i = args.index('++')
             argv = args[:i]
             args = args[i+1:]
         else:
             argv = args
-            args = []
         if fn == '-c':
             res = playScript(txt, name='__inline__', argv=argv)
         else:
@@ -891,17 +875,14 @@ def mkdir(path, clear=False, new=False):
     if new and path.exists():
         raise OSError(f"Path already exists: {path}")
     if clear and path.exists():
-        if path.is_dir():
-            shutil.rmtree(str(path))
-        else:
-            path.unlink()
+        path.removeTree(top=not new)
     os.makedirs(path, exist_ok=not new)
     return path
 
 
 def runtime():
     """Return the time elapsed since start of execution of the script."""
-    return time.perf_counter() - starttime
+    return _script_timer.value()
 
 
 def startGui():
