@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -46,6 +46,10 @@ from pyformex import process
 # We however also want to treat version numbers of a bunch of non-Python
 # packages, which may not follow Python's versioning style.
 
+class RequirementError(Exception):
+    pass
+
+
 class Version:
     """Abstract base class for version numbering classes.  Just provides
     constructor (__init__) and reproducer (__repr__), because those
@@ -70,10 +74,10 @@ class Version:
                             be an unparsed version string, or another
                             instance of your version class)
     """
-    def __init__ (self, vstring):
+    def __init__(self, vstring):
         self.parse(vstring)
 
-    def __repr__ (self):
+    def __repr__(self):
         return "%s ('%s')" % (self.__class__.__name__, str(self))
 
     def __eq__(self, other):
@@ -148,7 +152,7 @@ class SaneVersion(Version):
     """
     component_re = re.compile(r'(\d+ | [a-z]+ | \.)', re.VERBOSE)
 
-    def parse (self, vstring):
+    def parse(self, vstring):
         # I've given up on thinking I can reconstruct the version string
         # from the parsed tuple -- so I just store the string here for
         # use by __str__
@@ -162,13 +166,13 @@ class SaneVersion(Version):
                 pass
         self.version = components
 
-    def __str__ (self):
+    def __str__(self):
         return self.vstring
 
-    def __repr__ (self):
+    def __repr__(self):
         return "SaneVersion ('%s')" % str(self)
 
-    def _cmp (self, other):
+    def _cmp(self, other):
         if isinstance(other, str):
             other = SaneVersion(other)
         elif not isinstance(other, SaneVersion):
@@ -213,11 +217,11 @@ class Software():
     >>> Software.require('numpy')
     >>> Software.has('foo')
     Traceback (most recent call last):
-    ValueError: foo is not a registered Software
+    pyformex.software.RequirementError: foo is not a registered Software
     >>> foo = Software('foo')
     >>> Software.require('foo')
     Traceback (most recent call last):
-    ValueError: Required Software 'foo' (foo) not found
+    pyformex.software.RequirementError: Required Software 'foo' (foo) not found
     >>> Software.print_all()
       numpy (detected)
       foo (** Not Found **)
@@ -357,7 +361,7 @@ class Software():
         The optional argument check==True forces a new detection.
         """
         if name not in clas.register:
-            raise ValueError(f"{name} is not a registered {clas.__name__}")
+            raise RequirementError(f"{name} is not a registered {clas.__name__}")
         if check or clas.register[name].version is None:
             clas.register[name].detect(fatal=fatal, quiet=quiet)
         return clas.register[name].version
@@ -400,7 +404,8 @@ class Software():
     Probably it is not installed on your system.
     """
             pf.error(errmsg)
-            raise ValueError(f"Required {clas.__name__} '{name}' ({realname}) not found")
+            raise RequirementError(
+                f"Required {clas.__name__} '{name}' ({realname}) not found")
 
         else:
             if version is not None:
@@ -408,13 +413,13 @@ class Software():
                     realname = clas.register[name].name
                     errmsg = f"""..
 
-    **{clas.__name__} version {name} ({ver}) does not meet requirements ({version})!**
+**{clas.__name__} version {name} ({ver}) does not meet requirements ({version})!**
 
-    You activated some functionality requiring {clas.__name__} '{realname}'.
-    However, the required version for that software could not be found.
-    """
+You activated some functionality requiring {clas.__name__} '{realname}'.
+However, the required version for that software could not be found.
+"""
                     pf.error(errmsg)
-                    raise ValueError(
+                    raise RequirementError(
                         f"Required version ({version}) of {clas.__name__} "
                         f"'{name}' ({realname}) not found")
 
@@ -474,16 +479,16 @@ class Module(Software):
       pil (** Not Found **)
     >>> Module.has('foo')
     Traceback (most recent call last):
-    ValueError: foo is not a registered Module
+    pyformex.software.RequirementError: foo is not a registered Module
     >>> Module.require('foo')
     Traceback (most recent call last):
-    ValueError: foo is not a registered Module
+    pyformex.software.RequirementError: foo is not a registered Module
     >>> foo = Module('foo','FooBar')
     >>> Module.has('foo')
     ''
     >>> Module.require('foo')
     Traceback (most recent call last):
-    ValueError: Required Module 'foo' (FooBar) not found
+    pyformex.software.RequirementError: Required Module 'foo' (FooBar) not found
 
     Now fake a detection of Module 'foo'
 
@@ -494,8 +499,7 @@ class Module(Software):
     >>> Module.require('foo','>= 1.1.7')
     >>> Module.require('foo','>= 1.3.0')
     Traceback (most recent call last):
-    ValueError: Required version (>= 1.3.0) of Module 'foo' (FooBar) not found
-
+    pyformex.software.RequirementError: Required version (>= 1.3.0) of Module 'foo' (FooBar) not found
     """
 
     register = dict()
