@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -25,22 +25,44 @@
 ##  along with this program.  If not, see http://www.gnu.org/licenses/.
 ##
 
-"""track.py
+"""Add tracking facilities to any class.
+
+This module provides some functions to help in creating classes with
+tracking facilities. This can e.g. be use to detect if the contents of
+a list or dict has been changed.
+
+The tracking facility consists in marking some of the class' methods and
+count how many times any of these methods is used.
+
+Examples
+--------
+>>> TrackedDict = track_class_factory(dict)
+>>> D = TrackedDict({'a':1,'b':2})
+>>> print(D.hits)
+0
+>>> D['c'] = 3
+>>> print(D.hits)
+1
+>>> D.hits = 0
+>>> print(D.hits)
+0
+>>> D.update({'d':1,'b':3})
+>>> del D['a']
+>>> print(D.hits)
+2
 
-Functions for creating classes with access tracking facilities.
-This can e.g. be use to detect if the contents of a list or dict
-has been changed.
 """
 
 _attributes_ = ['track_methods']
 
 track_methods = [
-    '__setitem__', '__setslice__', '__delitem__', 'update', 'append', 'extend',
-    'add', 'insert', 'pop', 'popitem', 'remove', 'setdefault', '__iadd__'
+    '__delitem__', '__iadd__', '__imul__', '__ior__', '__setitem__',
+    'append', 'clear', 'extend', 'insert', 'pop', 'popitem', 'remove',
+    'setdefault', 'update',
 ]
 """
-List of names of methods that can possibly change an object
-of type dict or list.
+This list of methods that can possibly change an object
+of type dict or list is the default list of tracked methods.
 """
 
 
@@ -49,7 +71,7 @@ def track_decorator(func):
 
     The wrapper function increases the 'hits' attribute of the
     class and then executes the wrapped method.
-    Note that the class is passed as the first argument.
+    The class is passed as the first argument.
     """
 
     def wrapper(*args, **kw):
@@ -62,18 +84,12 @@ def track_decorator(func):
     return wrapper
 
 
-def track_class_factory(cls, name='', methods=track_methods):
+def track_class_factory(clas, name='', methods=track_methods):
     """Create a wrapper class with method tracking facilities.
 
-    Tracking a class counts the number of times any of the specified
-    class methods has been used.
-    Given an input class, this will return a class with tracking
-    facilities. The tracking occurs on all the specified methods.
-    The default will
-
     Parameters
     ----------
-    cls: class
+    clas: class
         The class to be tracked.
     name: str, optional
         The name of the class wrapper. If not provided, the name
@@ -92,27 +108,10 @@ def track_class_factory(cls, name='', methods=track_methods):
         A class wrapping the input class and tracking access to any of
         the specified methods. The class has an extra attribute 'hits'
         counting the number accesses to one of these methods.
-        This value can be reset to zero to track changes after some
+        The hits attribute can be reset to zero to track changes after some
         breakpoint.
-
-    Examples
-    --------
-    >>> TrackedDict = track_class_factory(dict)
-    >>> D = TrackedDict({'a':1,'b':2})
-    >>> print(D.hits)
-    0
-    >>> D['c'] = 3
-    >>> print(D.hits)
-    1
-    >>> D.hits = 0
-    >>> print(D.hits)
-    0
-    >>> D.update({'d':1,'b':3})
-    >>> del D['a']
-    >>> print(D.hits)
-    2
     """
-    new_dct = cls.__dict__.copy()
+    new_dct = clas.__dict__.copy()
     if 'hits' in new_dct:
         raise ValueError("The input class should not have an attribute 'hits'")
 
@@ -122,10 +121,16 @@ def track_class_factory(cls, name='', methods=track_methods):
             new_value = track_decorator(value)
             new_dct[key] = new_value
     new_dct['hits'] = 0
-    new_dct['__doc__'] = f"Tracked {cls.__name__} class"
+    new_dct['__doc__'] = f"""\
+Tracked {clas.__name__} class
+
+This {clas.__name__} class tracks the usage of the following methods:
+{track_methods}
+Usage of any of these methods increments the class' hits attribute.
+"""
     if not name:
-        name = 'Tracked' + cls.__name__.capitalize()
-    return type(name, (cls,), new_dct)
+        name = 'Tracked' + clas.__name__.capitalize()
+    return type(name, (clas,), new_dct)
 
 
 TrackedDict = track_class_factory(dict)
