@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2023 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 3.3  (Sun Mar 26 20:16:15 CEST 2023)
+##  This file is part of pyFormex 3.4  (Thu Nov 16 18:07:39 CET 2023)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -47,26 +47,12 @@ stored (using arrays) in two ways:
 In pyFormex, variable width tables were initially stored as 2D arrays:
 a remnant of the author's past FORTRAN experience. With a growing
 professional use of pyFormex involving ever larger models, it became clear
-that there was a large memory and speed penalty related to the use of
-2D arrays with lots of unused entries.
-This is illustrated in the following table, obtained on the
-inversion of a connectivity table of 10000 rows and 25 columns.
-The table shows the memory size of the inverse table, the time needed to
-compute it, and the time to compute both tables. The latter involves an
-extra conversion of the stored array to the other data type.
+that there was a large memory (and thus also speed) penalty related to the
+use of 2D arrays with lots of unused entries.
 
-====================  ===============  ==============  ===============
-Stored as:             2D (ndarray)     1D (Varray)     1D (Varray)
-Rows are sorted:       yes              yes             no
-====================  ===============  ==============  ===============
-Memory size                450000         250000        250000
-Time to create table       128 ms         49 ms         25ms
-Time to create both        169 ms         82 ms         57ms
-====================  ===============  ==============  ===============
-
-The memory and speed gains of using the Varray are important.
-The 2D array can even be faster generated by first creating the
-1D array, and then converting that to 2D.
+The Varray class can offer important memory and speed gains for large models.
+With many algorithms we even found that a 2D array result could be achieved
+faster by first constructing a Varray and then converting that to a 2D array.
 Not sorting the entries in the Varray provides a further gain.
 The Varray class defined below therefore does not sort the rows
 by default, but provides methods to sort them when needed.
@@ -75,12 +61,10 @@ by default, but provides methods to sort them when needed.
 import numpy as np
 
 from pyformex import arraytools as at
-from pyformex import utils
 
 
 class Varray():
-
-    """A variable width 2D integer array
+    """A variable width 2D integer array.
 
     This class provides an efficient way to store tables of
     nonnegative integers when the rows of the table may have
@@ -136,7 +120,7 @@ class Varray():
     The Varray prints in a user-friendly format:
 
     >>> print(Va)
-    Varray (4, (1, 3))
+    Varray (nrows=4, width=1..3)
       [0]
       [1 2]
       [0 2 4]
@@ -207,12 +191,12 @@ class Varray():
     Select takes multiple rows using indices or bool:
 
     >>> print(Va.select([1,3]))
-    Varray (2, (2, 2))
+    Varray (nrows=2, width=2..2)
       [1 2]
       [0 2]
     <BLANKLINE>
     >>> print(Va.select(Va.lengths==2))
-    Varray (2, (2, 2))
+    Varray (nrows=2, width=2..2)
       [1 2]
       [0 2]
     <BLANKLINE>
@@ -227,33 +211,18 @@ class Varray():
     [0 2]
 
     >>> print(Varray())
-    Varray (0, (0, 0))
+    Varray (nrows=0, width=0..0)
     <BLANKLINE>
 
     """
-    # REMOVED
-
-    # **Attributes**
-
-    # Attributes
-    # ----------
-    # nrows: int
-    #     The number of rows in the table
-    # width: int
-    #     The length of the longest row in the table
-    # size: int
-    #     The total number of entries in the table
-    # shape: tuple of two ints
-    #     The combined (``nrows``,``width``) values.
-
     def __init__(self, data=[], ind=None):
         """Initialize the Varray. See the class docstring."""
+        self._row = 0   # current row, for use iterators
 
         # If data is a Varray, just use its data
         if isinstance(data, Varray):
             self.data = data.data
             self.ind = data.ind
-            self._row = 0
             return
 
         # Allow for empty Varray
@@ -307,48 +276,56 @@ class Varray():
         # Store the data
         self.data = data.astype(at.Int)
         self.ind = ind.astype(at.Int)
-        self._memory = {}
-        # And the current row, for use in iterators
-        self._row = 0
-
-
-    def copy(self):
-        """Return a deep copy of the Varray"""
-        return Varray(self.data.copy(), self.ind.copy())
 
 
     # Attributes computed ad hoc, because cheap(er)
 
+    @property
+    def nrows(self):
+        """The number of rows in the Varray"""
+        return len(self.ind) - 1
 
     @property
     def lengths(self):
-        """Return the length of all rows of the Varray"""
+        """An array with the row lengths"""
         return self.ind[1:] - self.ind[:-1]
 
-
-    @property
-    def nrows(self):
-        """Return the number of rows in the Varray"""
-        return len(self.ind) - 1
-
-
-    @property
-    @utils.memoize
-    def width(self):
-        utils.warn("varray_width")
-        l = self.lengths
-        if len(l) > 0:
-            return l.min(), l.max()
-        else:
-            return 0, 0
-
     @property
     def minwidth(self):
-        return self.width[0]
+        """The length of the shortest row"""
+        l = self.lengths
+        return l.min() if len(l) > 0 else 0
 
     @property
     def maxwidth(self):
-        return self.width[1]
+        """The length of the longest row"""
+        l = self.lengths
+        return l.max() if len(l) > 0 else 0
+
+    @property
+    def width(self):
+        """A tuple with the minimum and maximum width"""
+        return self.minwidth, self.maxwidth
+
+    @property
+    def strwidth(self):
+        """A string with the mainimum and maximum row length"""
+        return f"{self.minwidth}..{self.maxwidth}"
+
+    @property
+    def size(self):
+        """The total number of elements in the Varray"""
+        return self.ind[-1]
+
+    @property
+    def shape(self):
+        """A tuple with the number of rows and the maximum row length"""
+        return (self.nrows, self.maxwidth)
+
+    @property
+    def dtype(self):
+        """Return the data type of the elements in the Varray"""
+        return self.data.dtype
 
 
     def __len__(self):
@@ -356,22 +333,9 @@ class Varray():
         return len(self.ind) - 1
 
 
-    @property
-    def size(self):
-        """Return the total number of elements in the Varray"""
-        return self.ind[-1]
-
-
-    @property
-    def shape(self):
-        """Return a tuple with the number of rows and maximum row length"""
-        return (self.nrows, self.maxwidth)
-
-
-    @property
-    def dtype(self):
-        """Return the data type of the elements in the Varray"""
-        return self.data.dtype
+    def copy(self):
+        """Return a deep copy of the Varray"""
+        return Varray(self.data.copy(), self.ind.copy())
 
 
     def length(self, i):
@@ -533,7 +497,7 @@ class Varray():
         >>> Va[2] = [1,3,5]
         >>> Va[3][1] = 1
         >>> print(Va)
-        Varray (4, (1, 3))
+        Varray (nrows=4, width=1..3)
           [0]
           [0 0]
           [1 3 5]
@@ -772,7 +736,7 @@ class Varray():
         >>> va = Varray([[0],[2,1],[4,0,2],[0,2]])
         >>> va.sort()
         >>> print(va)
-        Varray (4, (1, 3))
+        Varray (nrows=4, width=1..3)
           [0]
           [1 2]
           [0 2 4]
@@ -902,18 +866,18 @@ class Varray():
         >>> b = a.inverse()
         >>> c = b.inverse()
         >>> print(a,b,c)
-        Varray (4, (1, 2))
+        Varray (nrows=4, width=1..2)
           [0 1]
           [2 0]
           [1 2]
           [4]
-         Varray (5, (0, 2))
+         Varray (nrows=5, width=0..2)
           [0 1]
           [0 2]
           [1 2]
           []
           [3]
-         Varray (4, (1, 2))
+         Varray (nrows=4, width=1..2)
           [0 1]
           [0 2]
           [1 2]
@@ -921,7 +885,7 @@ class Varray():
         <BLANKLINE>
         >>> a = Varray([[-1,0,1],[0,2,-1],[2,1,1],[3,-2,0]])
         >>> print(a.inverse())
-        Varray (4, (1, 3))
+        Varray (nrows=4, width=1..3)
           [0 1 3]
           [0 2 2]
           [1 2]
@@ -961,10 +925,10 @@ class Varray():
 
     def __str__(self):
         """Nicely print the Varray"""
-        s = f"{self.__class__.__name__} ({self.nrows}, {self.width})\n"
-        for row in self:
-            s += '  ' + row.__str__() + '\n'
-        return s
+        s = [f"{self.__class__.__name__} "
+             f"(nrows={self.nrows}, width={self.strwidth})"]
+        s.extend([str(row) for row in self])
+        return '\n  '.join(s) + '\n'
 
 
     @classmethod
@@ -988,7 +952,7 @@ class Varray():
         >>> VA2 = Varray([[7,8],[9]])
         >>> VA = Varray.concatenate([VA0,VA1,VA2])
         >>> print(VA)
-        Varray (5, (1, 3))
+        Varray (nrows=5, width=1..3)
           [0 1]
           [2 3 4]
           [5 6]
@@ -1012,7 +976,7 @@ class Varray():
         ...     [[5,5], [6,6], [7,7]],
         ... ])
         >>> print(VA)
-        Varray (7, (2, 3))
+        Varray (nrows=7, width=2..3)
           [1 1]
           [2 2]
           [3 3 3]
